odump(1)

odump - Dumps selected parts of an object file

As shipped in IRIX 6.5.7. Last changed in IRIX 6.5.5.

NAME
     odump - Dumps selected parts of an object file

SYNOPSIS
     odump [-acfghilorstzFGPRLVDDsDiDcDlDrDtDgDh] file1 ...  fileN

IMPLEMENTATION
     IRIX systems

DESCRIPTION
     The odump command dumps selected parts of each object file.  It works
     on object files in either COFF or Elf formats.  But users are
     recommended to use elfdump(1) for Elf objects because it is better
     supported.

     This command works for object files and archives of object files.  It
     accepts one or more of these options:

     -a           Dumps the archive header for each member of the specified
                  archive file.

     -c           Dumps the string table.

     -f           Dumps each file header.

     -g           Dumps the global symbols from the symbol table of a MIPS
                  archive.

     -h           Dumps section headers.

     -i           Dumps the symbolic information header.

     -l           Dumps line number information.

     -o           Dumps each optional header.

     -s           Dumps section contents.

     -r           Dumps relocation information.

     -t           Dumps symbol table entries.

     -zname       Dumps line number entries for the specified function
                  name.

     -D           Dumps contents of .dynamic section.

     -Ds          Dumps contents of .dynstr section.

     -Di          Dumps contents of .reginfo section.

     -Dc          Dumps contents of .conflict section.

     -Dl          Dumps contents of .liblist section.

     -Dr          Dumps contents of .rel.dyn section.

     -Dt          Dumps contents of .dynsym section.

     -Dg          Dumps contents of .got section.

     -Dh          Dumps contents of .hash section.

     -dc          Dumps delta c++ class definitions.

     -di          Dumps delta c++ class instances.

     -ds          Dumps delta c++ delta symbols.

     -L           Interpret and print the contents of the .lib sections.

     -F           Dumps the file descriptor table.

     -G           Dumps the -G n histogram table.

     -P           Dumps the procedure descriptor table.

     -R           Dumps the relative file index table.

     -V           Dumps the version information.

     The odump command accepts these modifiers with the following options:

     -d number    Dumps the section number or a range of sections starting
                  at number and ending either at the last section number or
                  the number you specify with +d.

     +d number    Dumps sections in the range beginning with the first
                  section or beginning with the section you specify with
                  -d.

     -n name      Dumps information only about the specified name.  This
                  modifier works with -h, -s, -r, -l, and -t.

     -p           Does not print headers.

     -t index     Dumps only the indexed symbol table entry.  You can also
                  specify a range of symbol table entries by using the
                  modifier -t with the +t option.

     +t index     Dumps the symbol table entries in the specified range.
                  The range begins at the first symbol table entry or at
                  the entry specified by -t.  The range ends with the
                  specified indexed entry.

     -u           Underlines the name of the file for emphasis.

     -v           Dumps information symbolically rather than numerically
                  (for example, Static rather than 0X02).  You can specify
                  -v with all the options except -s.

     -z name,number
                  Dumps the specified line number entry or a range of line
                  numbers.  The range starts at the number for the named
                  function.

     +z number    Dumps line numbers for a specified range.  The range
                  starts at either the name or number specified by -z.  The
                  range ends with the number specified by +z.

     Optionally, an option and its modifier can be separated by using
     blanks.  The name can be separated from the number that modifies -z by
     replacing the comma with a blank.

     The odump command tries to format information in a helpful way,
     printing information in character, hexadecimal, octal, or decimal, as
     appropriate.

SEE ALSO
     a.out(4), ar(4)

     This man page is available only online.